@@ -2,8 +2,8 @@
 #include "buffer.h"
 #include "scan.h"
 
-int buffer_get_token(buffer* b,unsigned char* x,unsigned long int len,const unsigned char* charset,unsigned long int setlen) {
-  int blen;
+int buffer_get_token(buffer* b,char* x,unsigned long int len,const char* charset,unsigned long int setlen) {
+  unsigned long int blen;
 
   for (blen=0;blen<len;++blen) {
     register int r;
