@@ -2,9 +2,9 @@
 #include "buffer.h"
 #include "scan.h"
 
-int buffer_get_token_pred(buffer* b,unsigned char* x,unsigned long int len,
+int buffer_get_token_pred(buffer* b,char* x,unsigned long int len,
 			  string_predicate p) {
-  int blen;
+  unsigned int blen;
 
   for (blen=0;blen<len;++blen) {
     register int r;
