@@ -1,8 +1,8 @@
 #include "byte.h"
 #include "buffer.h"
 
-int buffer_getn(buffer* b,unsigned char* x,unsigned long int len) {
-  int blen;
+int buffer_getn(buffer* b,char* x,unsigned long int len) {
+  unsigned int blen;
 
   for(blen=0;blen<len;++blen) {
     register int r;
