@@ -1,8 +1,8 @@
 #include "byte.h"
 #include "buffer.h"
 
-int buffer_putalign(buffer* b,const unsigned char* buf,unsigned long int len) {
-  int tmp;
+int buffer_putalign(buffer* b,const char* buf,unsigned long int len) {
+  unsigned int tmp;
   while (len>(tmp=b->a-b->p)) {
     byte_copy(b->x+b->p, tmp, buf);
     b->p+=tmp;
