@@ -7,13 +7,14 @@
  *   4321:0:1:2:3:4:567:89ab
  * ->
  *   b.a.9.8.7.6.5.0.4.0.0.0.3.0.0.0.2.0.0.0.1.0.0.0.0.0.0.0.1.2.3.4.IP6.INT.
+ *   b.a.9.8.7.6.5.0.4.0.0.0.3.0.0.0.2.0.0.0.1.0.0.0.0.0.0.0.1.2.3.4.IP6.ARPA.
  */
 
-static inline char tohex(char c) {
+static char tohex(char c) {
   return c>=10?c-10+'a':c+'0';
 }
 
-int dns_name6_domain(char name[DNS_NAME6_DOMAIN],char ip[16])
+void dns_name6_domain(char name[DNS_NAME6_DOMAIN],const char ip[16],int t)
 {
   unsigned int j;
 
@@ -23,7 +24,9 @@ int dns_name6_domain(char name[DNS_NAME6_DOMAIN],char ip[16])
     name[j*4+2]=1;
     name[j*4+3]=tohex((unsigned char)ip[15-j] >> 4);
   }
-  byte_copy(name + 4*16,9,"\3ip6\3int\0");
-  return 4*16+9;
+  if (t==DNS_IP6_INT)
+    byte_copy(name + 4*16,9,"\3ip6\3int\0");
+  else if (t==DNS_IP6_ARPA)
+    byte_copy(name + 4*16,10,"\3ip6\4arpa\0");
 }
 
