@@ -1,6 +1,10 @@
 #include <unistd.h>
 #include <sys/types.h>
+#ifdef __MINGW32__
+#include <windows.h>
+#else
 #include <sys/mman.h>
+#endif
 #include "io_internal.h"
 
 void io_close(int64 d) {
@@ -10,7 +14,12 @@ void io_close(int64 d) {
     io_dontwantread(d);
     io_dontwantwrite(d);
     if (e->mmapped) {
+#ifdef __MINGW32__
+      UnmapViewOfFile(e->mmapped);
+      CloseHandle(e->mh);
+#else
       munmap(e->mmapped,e->maplen);
+#endif
       e->mmapped=0;
     }
   }
