@@ -12,7 +12,7 @@ extern char* mmap_read(const char* filename,unsigned long* filesize) {
 #ifdef __MINGW32__
   HANDLE fd,m;
   char* map;
-  fd=CreateFile(filename,GENERIC_READ,FILE_SHARE_READ,0,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,0);
+  fd=CreateFile(filename,GENERIC_READ,FILE_SHARE_READ|FILE_SHARE_WRITE|FILE_SHARE_DELETE,0,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,0);
   if (fd==INVALID_HANDLE_VALUE)
     return 0;
   m=CreateFileMapping(fd,0,PAGE_READONLY,0,0,NULL);
