@@ -3,6 +3,6 @@
 unsigned int scan_int(const char* src,int* dest) {
   long l;
   register int len=scan_long(src,&l);
-  *dest=l;
+  if (len) *dest=l;
   return len;
 }
