@@ -40,7 +40,7 @@ unsigned int fmt_ip6(char *s,const char ip[16])
       }
     }
   }
-  if (compressing) { *s++=':'; ++len; }
+  if (compressing) { if (s) *s++=':'; ++len; }
 
 /*  if (s) *s=0; */
   return len;
