@@ -6,9 +6,9 @@
  * When the strings are different, str_diff does not read bytes past the
  * first difference. */
 int str_diffn(const char* a, const char* b, unsigned long limit) {
-  register const char* s=a;
-  register const char* t=b;
-  register const char* u=t+limit;
+  register const unsigned char* s=(const unsigned char*)a;
+  register const unsigned char* t=(const unsigned char*)b;
+  register const unsigned char* u=t+limit;
   register int j;
   j=0;
   for (;;) {
