@@ -6,7 +6,7 @@
  * returns 1. If sa is unallocated, stralloc_catb is the same as
  * stralloc_copyb. If it runs out of memory, stralloc_catb leaves sa
  * alone and returns 0. */
-int stralloc_catb(stralloc *sa,const char *buf,unsigned int len) {
+int stralloc_catb(stralloc *sa,const char *buf,unsigned long int len) {
   if (stralloc_readyplus(sa,len)) {
     byte_copy(sa->s+sa->len,len,buf);
     sa->len+=len;
