@@ -1,7 +1,7 @@
 #include "stralloc.h"
 #include "fmt.h"
 
-int stralloc_catulong0(stralloc *sa,unsigned long in,unsigned int n) {
+int stralloc_catulong0(stralloc *sa,unsigned long int in,unsigned long int n) {
   if (stralloc_readyplus(sa,fmt_ulong0(0,in,n))) {
     sa->len+=fmt_ulong0(sa->s+sa->len,in,n);
     return 1;
