@@ -11,11 +11,11 @@ static inline int issafe(unsigned char c) {
 	  safe[str_chr(safe,c)]);
 }
 
-unsigned long fmt_urlencoded(char* dest,const char* src,unsigned long len) {
+unsigned long fmt_urlencoded2(char* dest,const char* src,unsigned long len,const char* escapeme) {
   register const unsigned char* s=(const unsigned char*) src;
   unsigned long written=0,i;
   for (i=0; i<len; ++i) {
-    if (!issafe(s[i])) {
+    if (!issafe(s[i]) || escapeme[str_chr(escapeme,s[i])]==s[i]) {
       if (dest) {
 	dest[written]='%';
 	dest[written+1]=fmt_tohex(s[i]>>4);
@@ -28,3 +28,7 @@ unsigned long fmt_urlencoded(char* dest,const char* src,unsigned long len) {
   }
   return written;
 }
+
+unsigned long fmt_urlencoded(char* dest,const char* src,unsigned long len) {
+  return fmt_urlencoded2(dest,src,len,"");
+}
